@@ -1,4 +1,4 @@
 from .task import ClassificationTask
 from .deploy import get_web_service_app
-from .corpus import NsmcCorpus, ClassificationDataset
+from .corpus import *
 from .arguments import ClassificationTrainArguments, ClassificationDeployArguments
\ No newline at end of file
