@@ -1,4 +1,4 @@
 from .arguments import NERTrainArguments, NERDeployArguments
-from .corpus import NERCorpus, NERDataset, NER_PAD_ID
+from .corpus import *
 from .task import NERTask
 from .deploy import get_web_service_app
